==> amity-sdk-7.5.1-alpha04-sources.jar: main/com/amity/socialcloud/sdk/api/video/stream/AmityStreamRepository.kt <==
package com.amity.socialcloud.sdk.api.video.stream

import com.amity.socialcloud.sdk.api.video.stream.query.AmityStreamQuery
import com.amity.socialcloud.sdk.model.core.file.AmityImage
import com.amity.socialcloud.sdk.model.video.stream.AmityStream
import com.amity.socialcloud.sdk.video.model.AmityBroadcastResolution
import com.amity.socialcloud.sdk.video.domain.stream.CreateStreamUseCase
import com.amity.socialcloud.sdk.video.domain.stream.DisposeStreamBroadcasterUseCase
import com.amity.socialcloud.sdk.video.domain.stream.FetchStreamUseCase
import com.amity.socialcloud.sdk.video.domain.stream.GetStreamUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Completable
import io.reactivex.rxjava3.core.Flowable
import io.reactivex.rxjava3.core.Single

class AmityStreamRepository internal constructor() {

    /* begin_public_function
      id: stream.query
      api_style: live_collection
    */
    fun getStreams(): AmityStreamQuery.Builder {
        return AmityStreamQuery.Builder()
    }
    /* end_public_function */

    fun fetchStream(streamId: String): Completable {
        return FetchStreamUseCase().execute(streamId)
    }

    /* begin_public_function
      id: stream.get
    */
    fun getStream(streamId: String): Flowable<AmityStream> {
        return GetStreamUseCase().execute(streamId)
    }
    /* end_public_function */

    /* begin_public_function
      id: stream.create
    */
    fun createStream(
        title: String,
        description: String,
        metadata: JsonObject? = null,
        thumbnailImage: AmityImage? = null,
        resolution: AmityBroadcastResolution,
    ): Single<AmityStream> {
        return CreateStreamUseCase().execute(
            title = title,
            description = description,
            resolution = resolution,
            metadata = metadata,
            thumbnailFileId = thumbnailImage?.getFileId()
        )
    }
    /* end_public_function */

    @Deprecated(
        message = "This function is deprecated, please use createStream(title: String, description: String, metadata: JsonObject?, thumbnailImage: AmityImage?, resolution: AmityBroadcastResolution) instead",
        replaceWith = ReplaceWith(
            "createStream(title: String, description: String, metadata: JsonObject?, thumbnailImage: AmityImage?, resolution: AmityBroadcastResolution)",
            "com.amity.socialcloud.sdk.api.video.stream.AmityStreamRepository"
        ),
    )
    fun createStream(
        title: String,
        description: String,
        resolution: AmityBroadcastResolution,
        thumbnailFileId: String? = null
    ): Single<AmityStream> {
        return CreateStreamUseCase().execute(
            title = title,
            description = description,
            resolution = resolution,
            thumbnailFileId = thumbnailFileId
        )
    }

    /* begin_public_function
      id: stream.dispose
    */
    fun disposeStream(streamId: String): Completable {
        return DisposeStreamBroadcasterUseCase().execute(streamId)
    }
    /* end_public_function */

}

==> amity-sdk-7.6.9-alpha04-sources.jar: main/com/amity/socialcloud/sdk/api/video/stream/AmityStreamRepository.kt <==
package com.amity.socialcloud.sdk.api.video.stream

import com.amity.socialcloud.sdk.api.video.stream.query.AmityStreamQuery
import com.amity.socialcloud.sdk.model.core.file.AmityImage
import com.amity.socialcloud.sdk.model.video.stream.AmityStream
import com.amity.socialcloud.sdk.video.model.AmityBroadcastResolution
import com.amity.socialcloud.sdk.video.domain.stream.CreateStreamUseCase
import com.amity.socialcloud.sdk.video.domain.stream.DisposeStreamBroadcasterUseCase
import com.amity.socialcloud.sdk.video.domain.stream.EditStreamUseCase
import com.amity.socialcloud.sdk.video.domain.stream.FetchStreamUseCase
import com.amity.socialcloud.sdk.video.domain.stream.GetStreamUseCase
import com.google.gson.JsonObject
import io.reactivex.rxjava3.core.Completable
import io.reactivex.rxjava3.core.Flowable
import io.reactivex.rxjava3.core.Single

class AmityStreamRepository internal constructor() {

    /* begin_public_function
      id: stream.query
      api_style: live_collection
    */
    fun getStreams(): AmityStreamQuery.Builder {
        return AmityStreamQuery.Builder()
    }
    /* end_public_function */

    fun fetchStream(streamId: String): Completable {
        return FetchStreamUseCase().execute(streamId)
    }

    /* begin_public_function
      id: stream.get
    */
    fun getStream(streamId: String): Flowable<AmityStream> {
        return GetStreamUseCase().execute(streamId)
    }
    /* end_public_function */

    /* begin_public_function
      id: stream.create
    */
    fun createStream(
        title: String,
        description: String,
        metadata: JsonObject? = null,
        thumbnailImage: AmityImage? = null,
        resolution: AmityBroadcastResolution,
        isSecure: Boolean? = null,
        channelEnabled: Boolean? = null,
    ): Single<AmityStream> {
        return CreateStreamUseCase().execute(
            title = title,
            description = description,
            resolution = resolution,
            metadata = metadata,
            thumbnailFileId = thumbnailImage?.getFileId(),
            isSecure = isSecure,
            channelEnabled = channelEnabled,
        )
    }
    /* end_public_function */

    fun editStream(
        streamId: String,
        channelEnabled: Boolean,
    ): Single<AmityStream> {
        return EditStreamUseCase().execute(
            streamId = streamId,
            channelEnabled = channelEnabled,
        )
    }

    @Deprecated(
        message = "This function is deprecated, please use createStream(title: String, description: String, metadata: JsonObject?, thumbnailImage: AmityImage?, resolution: AmityBroadcastResolution) instead",
        replaceWith = ReplaceWith(
            "createStream(title: String, description: String, metadata: JsonObject?, thumbnailImage: AmityImage?, resolution: AmityBroadcastResolution)",
            "com.amity.socialcloud.sdk.api.video.stream.AmityStreamRepository"
        ),
    )
    fun createStream(
        title: String,
        description: String,
        resolution: AmityBroadcastResolution,
        thumbnailFileId: String? = null,
        isSecure: Boolean? = null,
    ): Single<AmityStream> {
        return CreateStreamUseCase().execute(
            title = title,
            description = description,
            resolution = resolution,
            thumbnailFileId = thumbnailFileId,
            isSecure = isSecure,
        )
    }

    /* begin_public_function
      id: stream.dispose
    */
    fun disposeStream(streamId: String): Completable {
        return DisposeStreamBroadcasterUseCase().execute(streamId)
    }
    /* end_public_function */

}
